@@ -1,7 +1,7 @@
 /*
  * Peony-Qt's Library
  *
- * Copyright (C) 2019, Tianjin KYLIN Information Technology Co., Ltd.
+ * Copyright (C) 2020, KylinSoft Co., Ltd.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -47,19 +47,34 @@ public:
      */
     explicit FileRenameOperation(QString uri, QString newName);
 
+    void setAutoOverwrite () {
+//        m_auto_overwrite = true;
+        m_apply_all = OverWriteAll;
+    }
+
+    void setAutoBackup () {
+        m_apply_all = BackupAll;
+    }
+
+    void setAutoIgnore () {
+        m_apply_all = IgnoreAll;
+    }
+
     void run() override;
     std::shared_ptr<FileOperationInfo> getOperationInfo() override {
         return m_info;
     }
 
 private:
-    GFileCopyFlags m_default_copy_flag = GFileCopyFlags(G_FILE_COPY_NOFOLLOW_SYMLINKS|
-                                         G_FILE_COPY_ALL_METADATA);
-
+    ExceptionResponse prehandle(GError *err);
+    GFileCopyFlags m_default_copy_flag = GFileCopyFlags(G_FILE_COPY_NOFOLLOW_SYMLINKS | G_FILE_COPY_ALL_METADATA);
     QString m_uri = nullptr;
     QString m_new_name = nullptr;
+    QString m_old_name = nullptr;
 
     std::shared_ptr<FileOperationInfo> m_info = nullptr;
+
+    ExceptionResponse m_apply_all = Other;
 };
 
 }
